// DivideByN.v

/*	Generate one pulse for every N inputs.
 *  C. Vickery
 *	October, 2008
 */

module DivideByN
	#(	// Establish the value of N
		parameter 		N = 50_000_000
	)
	(
		input	wire	In,
		output	reg		Out
	);
	
	//	Number of bits needed to hold the value of N
	localparam 	M = log2(N);
	
	reg 		[M-1:0] counter;

	//	Count the number of input pulses
	always @ (posedge In)
	begin
		if ( counter == (N - 1))
		begin
			counter <= 0;
			Out <= 1'b1;
		end
		else
		begin
			counter <= counter - 1;
			Out <= 1'b0;
		end
	end

	//	Compile-time function to compute ceil(log2(X))
	function integer log2(input integer n);
		integer i;
	begin
		i = 0;
		while (n > 0)
		begin
			n = n >> 1;
			i = i + 1;
		end
		log2 = (i == 0) ? 1 : i;
	end
	endfunction
endmodule